==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/zh/chinese.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "上周二",
	"field-year": "年",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"field-minute": "分钟",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"field-thu-short-relative+0": "本周四",
	"field-thu-short-relative+1": "下周四",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-wed-narrow-relative+-1": "上周三",
	"field-year-narrow": "年",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "MMMd日",
	"field-week-relative+0": "本周",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下周",
	"field-month-relative+1": "下个月",
	"field-sun-narrow-relative+0": "本周日",
	"field-mon-short-relative+0": "本周一",
	"field-sun-narrow-relative+1": "下周日",
	"field-mon-short-relative+1": "下周一",
	"field-second-relative+0": "现在",
	"dateFormatItem-yyyyQQQ": "rU年QQQQ",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "rU年MMMdE",
	"dateFormatItem-yyyyMd": "r年MMMd",
	"field-day": "日",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上周六",
	"field-hour-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyMEd": "rU年MMMd，E",
	"field-wed-relative+-1": "上周三",
	"field-sat-narrow-relative+-1": "上周六",
	"field-second": "秒",
	"dateFormat-long": "rU年MMMd",
	"dateFormatItem-GyMMMd": "r年MMMd",
	"field-quarter": "季度",
	"field-week-short": "周",
	"field-tue-short-relative+0": "本周二",
	"field-tue-short-relative+1": "下周二",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-GyMMM": "rU年MMM",
	"field-month": "月",
	"field-day-narrow": "日",
	"field-minute-short": "分",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"dateFormat-medium": "r年MMMd",
	"dateFormatItem-yyyyMMMM": "rU年MMMM",
	"dateFormatItem-UMMM": "U年MMM",
	"dateFormatItem-yyyyM": "rU年MMM",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"field-year-short": "年",
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"腊"
	],
	"field-quarter-relative+-1": "上季度",
	"dateFormatItem-yyyyMMMd": "r年MMMd",
	"field-sat-relative+-1": "上周六",
	"dateFormatItem-Md": "M-d",
	"field-hour": "小时",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"dateFormat-full": "rU年MMMdEEEE",
	"dateFormatItem-UMd": "U年MMMd",
	"field-month-relative+-1": "上个月",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本周六",
	"field-fri-relative+0": "本周五",
	"field-sat-narrow-relative+1": "下周六",
	"field-fri-relative+1": "下周五",
	"field-sun-short-relative+0": "本周日",
	"field-sun-short-relative+1": "下周日",
	"field-week-relative+-1": "上周",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"field-quarter-relative+0": "本季度",
	"field-minute-relative+0": "此刻",
	"field-quarter-relative+1": "下季度",
	"field-wed-short-relative+-1": "上周三",
	"dateFormat-short": "r/M/d",
	"field-thu-short-relative+-1": "上周四",
	"dateFormatItem-yyyyMMMEd": "rU年MMMdE",
	"field-mon-narrow-relative+-1": "上周一",
	"dateFormatItem-MMMMd": "MMMMd日",
	"field-thu-narrow-relative+-1": "上周四",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "上周二",
	"dateFormatItem-yyyy": "rU年",
	"field-wed-short-relative+0": "本周三",
	"dateFormatItem-M": "MMM",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"field-wed-short-relative+1": "下周三",
	"field-sun-relative+-1": "上周日",
	"dateFormatItem-d": "d日",
	"field-weekday": "工作日",
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"dateFormatItem-MEd": "M-dE",
	"dateFormatItem-y": "rU年",
	"field-thu-narrow-relative+0": "本周四",
	"field-thu-narrow-relative+1": "下周四",
	"field-sun-narrow-relative+-1": "上周日",
	"field-mon-short-relative+-1": "上周一",
	"field-thu-relative+0": "本周四",
	"field-thu-relative+1": "下周四",
	"field-fri-short-relative+-1": "上周五",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-yMd": "r年MMMd",
	"field-week": "周",
	"dateFormatItem-Ed": "d日E",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"dateFormatItem-yyyyMMM": "rU年MMM",
	"field-fri-short-relative+0": "本周五",
	"field-fri-short-relative+1": "下周五",
	"dateFormatItem-yyyyQQQQ": "rU年QQQQ",
	"dateFormatItem-UMMMd": "U年MMMd",
	"field-hour-short": "小时",
	"field-month-narrow": "月",
	"field-hour-narrow": "小时",
	"field-fri-narrow-relative+-1": "上周五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-fri-relative+-1": "上周五",
	"field-tue-short-relative+-1": "上周二",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "本周一",
	"field-mon-narrow-relative+1": "下周一",
	"field-zone": "时区",
	"dateFormatItem-MMMEd": "MMMd日E",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上周日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"dateFormatItem-Gy": "rU年",
	"field-day-short": "日",
	"field-week-narrow": "周",
	"field-era": "纪元",
	"field-fri-narrow-relative+0": "本周五",
	"field-fri-narrow-relative+1": "下周五",
	"dateFormatItem-UM": "U年MMM"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/zh/chinese.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "本季度",
	"field-quarter-short-relative+1": "下季度",
	"field-tue-relative+-1": "上周二",
	"field-year": "年",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分钟",
	"field-month-narrow-relative+-1": "上个月",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"field-day-short-relative+-1": "昨天",
	"field-thu-short-relative+0": "本周四",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今天",
	"field-day-short-relative+-2": "前天",
	"field-thu-short-relative+1": "下周四",
	"field-day-relative+1": "明天",
	"field-week-narrow-relative+0": "本周",
	"field-day-relative+2": "后天",
	"field-week-narrow-relative+1": "下周",
	"dateFormatItem-EBhms": "EB h:mm:ss",
	"field-wed-narrow-relative+-1": "上周三",
	"field-year-narrow": "年",
	"field-era-short": "纪元",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "本周二",
	"field-year-narrow-relative+1": "明年",
	"field-tue-relative+1": "下周二",
	"field-weekdayOfMonth": "月中日",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "MMMd日",
	"field-weekdayOfMonth-narrow": "月中日",
	"field-week-relative+0": "本周",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下周",
	"field-month-relative+1": "下个月",
	"field-sun-narrow-relative+0": "本周日",
	"field-mon-short-relative+0": "本周一",
	"field-sun-narrow-relative+1": "下周日",
	"field-mon-short-relative+1": "下周一",
	"field-second-relative+0": "现在",
	"dateFormatItem-yyyyQQQ": "rU年QQQQ",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-weekOfMonth": "月中周",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "rU年MMMdE",
	"dateFormatItem-yyyyMd": "r年MMMd",
	"field-day": "日",
	"field-dayOfYear-short": "年中日",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上周六",
	"field-hour-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyMEd": "rU年MMMd，E",
	"field-second-short-relative+0": "现在",
	"field-wed-relative+-1": "上周三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上周六",
	"field-second": "秒",
	"dateFormat-long": "rU年MMMd",
	"dateFormatItem-GyMMMd": "r年MMMd",
	"field-hour-short-relative+0": "这一时间 / 此时",
	"field-quarter": "季度",
	"field-week-short": "周",
	"field-day-narrow-relative+0": "今天",
	"field-day-narrow-relative+1": "明天",
	"field-day-narrow-relative+2": "后天",
	"field-tue-short-relative+0": "本周二",
	"field-tue-short-relative+1": "下周二",
	"field-month-short-relative+-1": "上个月",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-GyMMM": "rU年MMM",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"dateFormat-medium": "r年MMMd",
	"dateFormatItem-yyyyMMMM": "rU年MMMM",
	"dateFormatItem-UMMM": "U年MMM",
	"dateFormatItem-yyyyM": "rU年MMM",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本周一",
	"field-day-narrow-relative+-1": "昨天",
	"field-year-short": "年",
	"field-mon-relative+1": "下周一",
	"field-day-narrow-relative+-2": "前天",
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"腊"
	],
	"field-quarter-relative+-1": "上季度",
	"dateFormatItem-yyyyMMMd": "r年MMMd",
	"field-dayperiod-narrow": "上午/下午",
	"field-week-narrow-relative+-1": "上周",
	"field-dayOfYear": "年中日",
	"field-sat-relative+-1": "上周六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M-d",
	"field-hour": "小时",
	"field-minute-narrow-relative+0": "此刻",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"dateFormat-full": "rU年MMMdEEEE",
	"dateFormatItem-UMd": "U年MMMd",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本周六",
	"field-fri-relative+0": "本周五",
	"field-sat-narrow-relative+1": "下周六",
	"field-fri-relative+1": "下周五",
	"dateFormatItem-EBhm": "EB h:mm",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下个月",
	"field-sun-short-relative+0": "本周日",
	"field-sun-short-relative+1": "下周日",
	"field-week-relative+-1": "上周",
	"field-quarter-short-relative+-1": "上季度",
	"field-minute-short-relative+0": "此刻",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"field-quarter-relative+0": "本季度",
	"field-minute-relative+0": "此刻",
	"field-quarter-relative+1": "下季度",
	"field-wed-short-relative+-1": "上周三",
	"dateFormat-short": "r/M/d",
	"dateFormatItem-Bh": "Bh时",
	"field-year-narrow-relative+-1": "去年",
	"field-thu-short-relative+-1": "上周四",
	"dateFormatItem-yyyyMMMEd": "rU年MMMdE",
	"field-mon-narrow-relative+-1": "上周一",
	"dateFormatItem-MMMMd": "MMMMd日",
	"field-thu-narrow-relative+-1": "上周四",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "月中周",
	"field-tue-narrow-relative+-1": "上周二",
	"dateFormatItem-yyyy": "rU年",
	"dateFormatItem-M": "MMM",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"field-wed-short-relative+0": "本周三",
	"field-wed-short-relative+1": "下周三",
	"field-sun-relative+-1": "上周日",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "现在",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "工作日",
	"field-day-short-relative+0": "今天",
	"field-quarter-narrow-relative+0": "本季度",
	"field-day-short-relative+1": "明天",
	"field-sat-relative+0": "本周六",
	"field-quarter-narrow-relative+1": "下季度",
	"dateFormatItem-h": "ah时",
	"field-day-short-relative+2": "后天",
	"field-sat-relative+1": "下周六",
	"field-week-short-relative+0": "本周",
	"field-week-short-relative+1": "下周",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"腊月"
	],
	"field-dayOfYear-narrow": "年中日",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下个月",
	"field-weekdayOfMonth-short": "月中日",
	"dateFormatItem-MEd": "M-dE",
	"field-zone-narrow": "时区",
	"dateFormatItem-y": "rU年",
	"field-thu-narrow-relative+0": "本周四",
	"field-sun-narrow-relative+-1": "上周日",
	"field-mon-short-relative+-1": "上周一",
	"field-thu-narrow-relative+1": "下周四",
	"field-thu-relative+0": "本周四",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上周五",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-yMd": "r年MMMd",
	"field-week": "周",
	"dateFormatItem-Ed": "d日E",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"field-quarter-narrow-relative+-1": "上季度",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "rU年MMM",
	"field-dayperiod-short": "上午/下午",
	"field-year-short-relative+1": "明年",
	"field-fri-short-relative+0": "本周五",
	"field-fri-short-relative+1": "下周五",
	"field-week-short-relative+-1": "上周",
	"field-hour-narrow-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyQQQQ": "rU年QQQQ",
	"dateFormatItem-UMMMd": "U年MMMd",
	"field-hour-short": "小时",
	"field-zone-short": "时区",
	"field-month-narrow": "月",
	"field-hour-narrow": "小时",
	"field-fri-narrow-relative+-1": "上周五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-era-narrow": "纪元",
	"field-fri-relative+-1": "上周五",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-tue-short-relative+-1": "上周二",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "本周一",
	"field-mon-narrow-relative+1": "下周一",
	"field-year-short-relative+-1": "去年",
	"field-zone": "时区",
	"dateFormatItem-MMMEd": "MMMd日E",
	"field-weekOfMonth-narrow": "月中周",
	"field-weekday-narrow": "工作日",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上周日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-weekday-short": "工作日",
	"dateFormatItem-Bhm": "Bh:mm",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"dateFormatItem-Gy": "rU年",
	"field-day-short": "日",
	"field-week-narrow": "周",
	"field-era": "纪元",
	"field-fri-narrow-relative+0": "本周五",
	"dateFormatItem-UM": "U年MMM",
	"field-fri-narrow-relative+1": "下周五"
}
//end v1.x content
);
